@@ -11,17 +11,15 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from typing import TYPE_CHECKING, Any, Type
+from typing import Any, Type
 
 import torch
 import transformers
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
+from transformers.models.auto.auto_factory import _BaseAutoModelClass
 
 from lightning_transformers.core import TaskTransformer
 
-if TYPE_CHECKING:
-    from transformers import AutoModel
-
 
 class LanguageModelingTransformer(TaskTransformer):
     """Defines ``LightningModule`` for the Language Modeling Task.
@@ -33,7 +31,7 @@ class LanguageModelingTransformer(TaskTransformer):
     """
 
     def __init__(
-        self, *args, downstream_model_type: Type["AutoModel"] = transformers.AutoModelForCausalLM, **kwargs
+        self, *args, downstream_model_type: Type[_BaseAutoModelClass] = transformers.AutoModelForCausalLM, **kwargs
     ) -> None:
         super().__init__(downstream_model_type, *args, **kwargs)
 
@@ -63,7 +61,7 @@ class LanguageModelingTransformer(TaskTransformer):
     def hf_pipeline_task(self) -> str:
         return "text-generation"
 
-    def generate(self, text: str, device: torch.device = torch.device("cpu")) -> Any:
+    def generate(self, text: str, device: torch.device = torch.device("cpu"), **kwargs) -> Any:
         if self.tokenizer is None:
             raise MisconfigurationException(
                 "A tokenizer is required to use the `generate` function. "
@@ -71,4 +69,4 @@ class LanguageModelingTransformer(TaskTransformer):
             )
         inputs = self.tokenizer(text, return_tensors="pt")
         inputs = inputs.to(device)
-        return self.model.generate(inputs["input_ids"])
+        return self.model.generate(inputs["input_ids"], **kwargs)
