@@ -11,11 +11,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from lightning_transformers.core.nlp.seq2seq import Seq2SeqDataModule
+from lightning_transformers.core.seq2seq.data import Seq2SeqDataModule
 
 
 class SummarizationDataModule(Seq2SeqDataModule):
-    """
-    Defines the ``LightningDataModule`` for Summarization Datasets.
-    """
-    pass
+    """Defines the ``LightningDataModule`` for Summarization Datasets."""
+
+    ...
